@@ -8,15 +8,8 @@
 ## ------------------------------------------------------------------------
 library(sparsevar)
 
-## ---- cache = TRUE-------------------------------------------------------
-set.seed(1)
-sim <- simulateVAR(N = 20, p = 2)
-
-## ---- cache = TRUE-------------------------------------------------------
-fit <- fitVAR(sim$series, p = 2)
-
 ## ------------------------------------------------------------------------
-plotComparisonVAR(sim, fit)
+plotVAR(sim, fit)
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  irf <- impulseResponse(fit)
